@@ -29,6 +29,7 @@
 
 #include <sigc++/bind.h>
 
+using std::string;
 using std::ostringstream;
 using std::endl;
 
@@ -93,6 +94,7 @@ namespace ICQ2000 {
 
     m_status_wanted = STATUS_OFFLINE;
     m_invisible_wanted = false;
+    m_web_aware = false;
 
     m_ext_ip = 0;
     m_use_portrange = false;
@@ -670,11 +672,12 @@ namespace ICQ2000 {
       c->setDirect(true); // reset flags when a user goes online
       c->setStatus( Contact::MapICQStatusToStatus(userinfo.getStatus()),
 		    Contact::MapICQStatusToInvisible(userinfo.getStatus()) );
-      c->setExtIP( userinfo.getExtIP() );
-      c->setLanIP( userinfo.getLanIP() );
-      c->setExtPort( userinfo.getExtPort() );
-      c->setLanPort( userinfo.getLanPort() );
-      c->setTCPVersion( userinfo.getTCPVersion() );
+
+      if ( userinfo.getExtIP() != 0 ) c->setExtIP( userinfo.getExtIP() );
+      if ( userinfo.getLanIP() != 0 ) c->setLanIP( userinfo.getLanIP() );
+      if ( userinfo.getLanPort() != 0 ) c->setLanPort( userinfo.getLanPort() );
+      if ( userinfo.getTCPVersion() != 0 ) c->setTCPVersion( userinfo.getTCPVersion() );
+
       c->set_signon_time( userinfo.getSignonDate() );
       if (userinfo.contains_capabilities())
 	c->set_capabilities( userinfo.get_capabilities() );
@@ -847,7 +850,7 @@ namespace ICQ2000 {
     if (m_invisible_wanted)
       FLAPwrapSNAC(b, AddVisibleSNAC(m_visible_list) );
         
-    SetStatusSNAC sss(Contact::MapStatusToICQStatus(m_status_wanted, m_invisible_wanted));
+    SetStatusSNAC sss(Contact::MapStatusToICQStatus(m_status_wanted, m_invisible_wanted), m_web_aware);
 
     sss.setSendExtra(true);
     sss.setIP( m_serverSocket.getLocalIP() );
@@ -984,7 +987,7 @@ namespace ICQ2000 {
 	ParseCh4(sb,seq_num);
 	break;
       default:
-	ostr << "FLAP on unrecognised channel 0x" << hex << (int)channel;
+	ostr << "FLAP on unrecognised channel 0x" << std::hex << (int)channel;
 	SignalLog(LogEvent::WARN, ostr.str());
 	break;
       }
@@ -995,7 +998,7 @@ namespace ICQ2000 {
 	 * as it probably means they are faulty
 	 */
 	ostringstream ostr;
-	ostr  << "Buffer pointer not at end after parsing FLAP was: 0x" << hex << sb.pos()
+	ostr  << "Buffer pointer not at end after parsing FLAP was: 0x" << std::hex << sb.pos()
 	      << " should be: 0x" << sb.size();
 	SignalLog(LogEvent::WARN, ostr.str());
       }
@@ -1148,7 +1151,7 @@ namespace ICQ2000 {
 
     if (dynamic_cast<RawSNAC*>(snac)) {
       ostringstream ostr;
-      ostr << "Unknown SNAC packet received - Family: 0x" << hex << snac->Family()
+      ostr << "Unknown SNAC packet received - Family: 0x" << std::hex << snac->Family()
 	   << " Subtype: 0x" << snac->Subtype();
       SignalLog(LogEvent::WARN, ostr.str());
     }
@@ -1172,7 +1175,7 @@ namespace ICQ2000 {
 	RedirectTLV *r = static_cast<RedirectTLV*>(tlvlist[TLV_Redirect]);
 	ostringstream ostr;
 	ostr << "Redirected to: " << r->getHost();
-	if (r->getPort() != 0) ostr << " port: " << dec << r->getPort();
+	if (r->getPort() != 0) ostr << " port: " << std::dec << r->getPort();
 	SignalLog(LogEvent::INFO, ostr.str());
 
 	m_bosHostname = r->getHost();
@@ -1536,16 +1539,6 @@ namespace ICQ2000 {
   void Client::SendViaServer(MessageEvent *ev) {
     ContactRef c = ev->getContact();
 
-    if (m_self->getStatus() == STATUS_OFFLINE) {
-      ev->setFinished(true);
-      ev->setDelivered(false);
-      ev->setDirect(false);
-      ev->setDeliveryFailureReason(MessageEvent::Failed_NotConnected);
-      messageack.emit(ev);
-      delete ev;
-      return;
-    }
-
     if (ev->getType() == MessageEvent::Normal
 	|| ev->getType() == MessageEvent::URL) {
       
@@ -1615,6 +1608,16 @@ namespace ICQ2000 {
 
   void Client::SendViaServerAdvanced(MessageEvent *ev) 
   {
+    if (m_state == NOT_CONNECTED) {
+      ev->setFinished(true);
+      ev->setDelivered(false);
+      ev->setDirect(false);
+      ev->setDeliveryFailureReason(MessageEvent::Failed_NotConnected);
+      messageack.emit(ev);
+      delete ev;
+      return;
+    }
+
     ContactRef c = ev->getContact();
     UINICQSubType *ist = m_message_handler.handleOutgoing(ev);
     ist->setAdvanced(true);
@@ -1635,6 +1638,15 @@ namespace ICQ2000 {
   
   void Client::SendViaServerNormal(MessageEvent *ev)
   {
+    if (m_state == NOT_CONNECTED) {
+      ev->setFinished(true);
+      ev->setDelivered(false);
+      ev->setDirect(false);
+      ev->setDeliveryFailureReason(MessageEvent::Failed_NotConnected);
+      messageack.emit(ev);
+      return;
+    }
+
     ContactRef c = ev->getContact();
     UINICQSubType *ist = m_message_handler.handleOutgoing(ev);
     ist->setAdvanced(false);
@@ -1651,6 +1663,7 @@ namespace ICQ2000 {
     if ((cev = dynamic_cast<ICQMessageEvent*>(ev)) != NULL) cev->setOfflineMessage(true);
     
     messageack.emit(ev);
+    delete ist;
   }
   
   void Client::PingServer() {
@@ -1714,7 +1727,7 @@ namespace ICQ2000 {
 	FLAPwrapSNAC( b, AddVisibleSNAC(m_visible_list) );
       }
 	
-      FLAPwrapSNAC( b, SetStatusSNAC(Contact::MapStatusToICQStatus(st, inv)) );
+      FLAPwrapSNAC( b, SetStatusSNAC(Contact::MapStatusToICQStatus(st, inv), m_web_aware) );
       
       if (m_self->isInvisible() && !inv) {
 	// invisible -> visible
@@ -1729,8 +1742,11 @@ namespace ICQ2000 {
       m_invisible_wanted = inv;
       
       // start connecting if not already
-      if (m_state == NOT_CONNECTED)
+      if (m_state == NOT_CONNECTED) {
+	ConnectingEvent ev;
+        connecting.emit(&ev);
 	ConnectAuthorizer(AUTH_AWAITING_CONN_ACK);
+      }
     }
   }
 
@@ -1756,6 +1772,16 @@ namespace ICQ2000 {
     setStatus(m_status_wanted, inv);
   }
 
+  void Client::setWebAware(bool wa)
+  {
+    if (m_web_aware!=wa)
+    {
+      m_web_aware = wa;
+      if (m_self->getStatus() != STATUS_OFFLINE)
+      setStatus(m_status_wanted, m_invisible_wanted);
+    }
+  }
+
   /**
    *  Get your current status.
    *
@@ -1775,6 +1801,27 @@ namespace ICQ2000 {
     return m_self->isInvisible();
   }
 
+  /**
+   *  Get the last requested status
+   */
+  Status Client::getStatusWanted() const 
+  {
+    return m_status_wanted;
+  }
+  
+  /**
+   *  Get the last invisibility status wanted
+   */
+  bool Client::getInvisibleWanted() const
+  {
+    return m_invisible_wanted;
+  }
+
+  bool Client::getWebAware() const
+  {
+    return m_web_aware;
+  }
+
   void Client::contactlist_cb(ContactListEvent *ev)
   {
     ContactRef c = ev->getContact();
@@ -2098,7 +2145,7 @@ namespace ICQ2000 {
     return ev;
   }
 
-  SearchResultEvent* Client::searchForContacts(const std::string& keyword)
+  SearchResultEvent* Client::searchForContacts(const string& keyword)
   {
     SearchResultEvent *ev = new SearchResultEvent( SearchResultEvent::Keyword );
     unsigned int reqid = NextRequestID();
