@@ -24,6 +24,8 @@
 #include "sstream_fix.h"
 #include <memory>
 
+using std::string;
+using std::list;
 using std::ostringstream;
 using std::auto_ptr;
 
@@ -64,6 +66,9 @@ namespace ICQ2000 {
     case MSG_Type_EmailEx:
       ist = new EmailExICQSubType();
       break;
+    case MSG_Type_WebPager:
+      ist = new WebPagerICQSubType();
+      break;
     case MSG_Type_UserAdd:
       ist = new UserAddICQSubType();
       break;
@@ -77,7 +82,7 @@ namespace ICQ2000 {
     default:
       {
 	ostringstream ostr;
-	ostr << "Unknown ICQ Subtype: 0x" << hex << (int) type;
+	ostr << "Unknown ICQ Subtype: 0x" << std::hex << (int) type;
 	throw ParseException(ostr.str());
       }
     }
@@ -172,6 +177,9 @@ namespace ICQ2000 {
 	>> priority;
       m_urgent = priority & Priority_Urgent;
       m_tocontactlist = priority & Priority_ToContactList;
+      if (!m_urgent && priority != Priority_Normal && priority != 0)
+	m_tocontactlist = true;
+      // the official clients seem fairly lenient on what they'll accept in status flags
     }
 
     if (!m_ack) {
@@ -636,6 +644,10 @@ namespace ICQ2000 {
 
   unsigned char AuthAccICQSubType::getType() const { return MSG_Type_AuthAcc; }
 
+  // ============================================================================
+  //  Email Express message
+  // ============================================================================
+
   EmailExICQSubType::EmailExICQSubType() { }
 
   void EmailExICQSubType::ParseBody(Buffer& b) {
@@ -671,6 +683,49 @@ namespace ICQ2000 {
 
   string EmailExICQSubType::getSender() const { return m_sender; }
 
+  // ============================================================================
+  //  Web Pager message
+  // ============================================================================
+
+  WebPagerICQSubType::WebPagerICQSubType() { }
+
+  void WebPagerICQSubType::ParseBody(Buffer& b) {
+    string text;
+
+    b.UnpackUint16StringNull(text);
+
+    list<string> fields;
+    string_split( text, string("\xfe"), 6, fields);
+
+    list<string>::iterator iter = fields.begin();
+    m_sender = b.ServerToClientCC(*(iter++));
+    ++iter; // ???
+    ++iter; // ???
+    m_email = b.ServerToClientCC(*(iter++));
+    ++iter; // ???
+    m_message = b.ServerToClientCC(*(iter++));
+  }
+
+  void WebPagerICQSubType::OutputBody(Buffer& b) const {
+    // never sent
+  }
+
+  unsigned short WebPagerICQSubType::Length() const {
+    return 0;
+  }
+
+  unsigned char WebPagerICQSubType::getType() const { return MSG_Type_WebPager; }
+
+  string WebPagerICQSubType::getMessage() const { return m_message; }
+
+  string WebPagerICQSubType::getEmail() const { return m_email; }
+
+  string WebPagerICQSubType::getSender() const { return m_sender; }
+
+  // ============================================================================
+  //  "You were added" message
+  // ============================================================================
+
   UserAddICQSubType::UserAddICQSubType() { }
 
   UserAddICQSubType::UserAddICQSubType(const string& alias, const string& firstname,
