@@ -23,6 +23,8 @@
 
 #include <libicq2000/Contact.h>
 
+using std::string;
+
 namespace ICQ2000 {
 
   // ============================================================================
@@ -124,6 +126,15 @@ namespace ICQ2000 {
   RemoveSocketHandleEvent::RemoveSocketHandleEvent(int fd)
     : SocketEvent(fd) { }
 
+  // ============================================================================
+  //  Connecting Event
+  // ============================================================================
+
+  /**
+   *  Simple constructor for a ConnectingEvent.
+   */
+  ConnectingEvent::ConnectingEvent() { }
+
   // ============================================================================
   //  Connected Event
   // ============================================================================
@@ -614,6 +625,11 @@ namespace ICQ2000 {
    */
   void NormalMessageEvent::setBackground(unsigned int b) { m_background = b; }
 
+  ICQMessageEvent* NormalMessageEvent::copy() const
+  {
+    return new NormalMessageEvent(*this);
+  }
+
   // ============================================================================
   //  URL Message
   // ============================================================================
@@ -658,6 +674,11 @@ namespace ICQ2000 {
    */
   string URLMessageEvent::getURL() const { return m_url; }
 
+  ICQMessageEvent* URLMessageEvent::copy() const
+  {
+    return new URLMessageEvent(*this);
+  }
+
   // ============================================================================
   //  SMS Message
   // ============================================================================
@@ -818,6 +839,11 @@ namespace ICQ2000 {
 
   MessageEvent::MessageType AwayMessageEvent::getType() const { return MessageEvent::AwayMessage; }
 
+  ICQMessageEvent* AwayMessageEvent::copy() const
+  {
+    return new AwayMessageEvent(*this);
+  }
+
   // ============================================================================
   //  Authorisation Request
   // ============================================================================
@@ -854,6 +880,11 @@ namespace ICQ2000 {
    */
   string AuthReqEvent::getMessage() const { return m_message; }
 
+  ICQMessageEvent* AuthReqEvent::copy() const
+  {
+    return new AuthReqEvent(*this);
+  }
+
   // ============================================================================
   //  Authorisation Acknowledgement
   // ============================================================================
@@ -925,6 +956,11 @@ namespace ICQ2000 {
    */
   string AuthAckEvent::getMessage() const { return m_message; }
 
+  ICQMessageEvent* AuthAckEvent::copy() const
+  {
+    return new AuthAckEvent(*this);
+  }
+
   // ============================================================================
   //  E-mail Express message
   // ============================================================================
@@ -942,7 +978,22 @@ namespace ICQ2000 {
 
   MessageEvent::MessageType EmailExEvent::getType() const { return MessageEvent::EmailEx; }
 
-  unsigned int EmailExEvent::getSenderUIN() const { return m_contact->getUIN(); }
+  // ============================================================================
+  //  Web Pager message
+  // ============================================================================
+
+  WebPagerEvent::WebPagerEvent(ContactRef c, const string& email,
+			       const string& sender, const string& msg)
+    : MessageEvent(c), m_sender(sender), m_email(email), m_message(msg)
+  { }
+
+  string WebPagerEvent::getMessage() const { return m_message; }
+
+  string WebPagerEvent::getEmail() const { return m_email; }
+
+  string WebPagerEvent::getSender() const { return m_sender; }
+
+  MessageEvent::MessageType WebPagerEvent::getType() const { return MessageEvent::WebPager; }
 
   // ============================================================================
   //  "You were added" message
@@ -954,6 +1005,11 @@ namespace ICQ2000 {
 
   unsigned int UserAddEvent::getSenderUIN() const { return m_contact->getUIN(); }
 
+  ICQMessageEvent* UserAddEvent::copy() const
+  {
+    return new UserAddEvent(*this);
+  }
+
   // ============================================================================
   //  Email Message
   // ============================================================================
